/**
 * Determine the mouse position
 *
 * @param event the canvas event
 * @returns *[] tuple of position x,y
 * @private
 */
'use strict';

Object.defineProperty(exports, '__esModule', {
    value: true
});
var pointerPosition = function pointerPosition(event) {
    event = event || window.event;
    var target = event.target || event.srcElement,
        style = target.currentStyle || window.getComputedStyle(target, null),
        borderLeftWidth = parseInt(style['borderLeftWidth'], 10),
        borderTopWidth = parseInt(style['borderTopWidth'], 10),
        rect = target.getBoundingClientRect(),
        _x = event.clientX - borderLeftWidth - rect.left,
        _y = event.clientY - borderTopWidth - rect.top,
        _touchX = event.changedTouches ? event.changedTouches[0].clientX - borderLeftWidth - rect.left : null,
        _touchY = event.changedTouches ? event.changedTouches[0].clientY - borderTopWidth - rect.top : null;
    return [_x || _touchX, _y || _touchY];
};

exports.pointerPosition = pointerPosition;
//function getMouseCoords(canvas, event)
//{
//    var pointer = canvas.getPointer(event.e);
//    var posX = pointer.x;
//    var posY = pointer.y;
//    console.log(posX+", "+posY);    // Log to console
//}

/**
 * Calculate the distance of two x,y points
 *
 * @param point1 an object with x,y attributes representing the start point
 * @param point2 an object with x,y attributes representing the end point
 *
 * @returns {number}
 */
var linearDistance = function linearDistance(point1, point2) {
    var xs = point2.x - point1.x;
    var ys = point2.y - point1.y;
    return Math.sqrt(xs * xs + ys * ys);
};

exports.linearDistance = linearDistance;
/**
 * Return a random uuid of the form xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx
 * @returns {string}
 */
var uuid4 = function uuid4() {
    var uuid = '',
        ii = undefined;
    for (ii = 0; ii < 32; ii += 1) {
        switch (ii) {
            case 8:
            case 20:
                uuid += '-';
                uuid += (Math.random() * 16 | 0).toString(16);
                break;
            case 12:
                uuid += '-';
                uuid += '4';
                break;
            case 16:
                uuid += '-';
                uuid += (Math.random() * 4 | 8).toString(16);
                break;
            default:
                uuid += (Math.random() * 16 | 0).toString(16);
        }
    }
    return uuid;
};
exports.uuid4 = uuid4;